package com.steerinfo.ems.emssecuernode.controller;

import com.steerinfo.ems.Utils.DateUtils;
import com.steerinfo.ems.emssecuernode.model.EmsSecuerNode;
import com.steerinfo.ems.emssecuernode.service.IEmsSecuerNodeService;
import com.steerinfo.framework.controller.BaseRESTfulController;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageList;
import com.steerinfo.framework.utils.collection.ListUtils;

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Primary;
import org.springframework.web.bind.annotation.*;

import java.util.*;

/**
 * EmsSecuerNode RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2023-04-20 03:07
 * 类描述
 * 修订历史：
 * 日期：2023-04-20
 * 作者：generator
 * 参考：
 * 描述：EmsSecuerNode RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@RestController
@RequestMapping("/${api.version}/emssecuernodes")
public class EmsSecuerNodeController extends BaseRESTfulController {

    @Autowired
    IEmsSecuerNodeService emsSecuerNodeService;

    @ApiOperation(value="获取列表", notes="分页查询")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
        @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer")
    })
    //@RequiresPermissions("emssecuernode:view")
    @GetMapping(value = "/")
    public RESTfulResult list(@RequestParam HashMap parmas,Integer pageNum, Integer pageSize){
        PageList<EmsSecuerNode> list = emsSecuerNodeService.queryForPage(parmas, pageNum, pageSize);
        return success(list);
    }

    @ApiOperation(value="获取列表", notes="分页模糊查询")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
        @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer")
    })
    //@RequiresPermissions("emssecuernode:view")
    @GetMapping(value = "/like/")
    public RESTfulResult listLike(@RequestParam HashMap parmas,Integer pageNum, Integer pageSize){
        PageList<EmsSecuerNode> list = emsSecuerNodeService.queryLikeForPage(parmas, pageNum, pageSize);
        return success(list);
    }
    
    @ApiOperation(value="创建", notes="根据EmsSecuerNode对象创建")
    @ApiImplicitParam(name = "emsSecuerNode", value = "详细实体emsSecuerNode", required = true, dataType = "EmsSecuerNode")
    //@RequiresPermissions("emssecuernode:create")
    @PostMapping(value = "/")
    public RESTfulResult add(@ModelAttribute EmsSecuerNode model){
        String createTime= DateUtils.getCurrentTime("yyyy-MM-dd HH:mm:ss");
            model.setItemstatus((short) 100);
            model.setItemtype((short) 100);
        model.setCreatetime(createTime);
        model.setId(UUID.randomUUID().toString().trim());
        EmsSecuerNode emsSecuerNode = emsSecuerNodeService.add(model);
        return success(emsSecuerNode);
    }

    @ApiOperation(value="获取详细信息", notes="根据url的id来获取详细信息")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "String")
    //@RequiresPermissions("emssecuernode:view")
    @GetMapping(value = "/{id}")
    public RESTfulResult get(@PathVariable String id){
        EmsSecuerNode emsSecuerNode = emsSecuerNodeService.getById(id);
        return success(emsSecuerNode);
    }

    @ApiOperation(value="更新详细信息", notes="根据url的id来指定更新对象，并根据传过来的emsSecuerNode信息来更新详细信息")
    @ApiImplicitParams({
        @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "String"),
        @ApiImplicitParam(name = "emsSecuerNode", value = "详细实体emsSecuerNode", required = true, dataType = "EmsSecuerNode")
    })
    //@RequiresPermissions("emssecuernode:update")
    @PutMapping(value = "/{id}", produces  = "application/json;charset=UTF-8")
    public RESTfulResult update(@PathVariable String id, @RequestBody EmsSecuerNode model){
        model.setId(id);
        EmsSecuerNode emsSecuerNode = emsSecuerNodeService.modify(model);
        return success(emsSecuerNode);
    }

    @ApiOperation(value="删除", notes="根据url的id来指定删除对象")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "String")
    //@RequiresPermissions("emssecuernode:delete")
    @DeleteMapping(value = "/{id}")//String
    public RESTfulResult delete(@PathVariable String id){
    	List<String> list = Arrays.asList(id.split(","));
    	if(ListUtils.isNotEmpty(list)) {
	    	List<String> ids = ListUtils.convertList(list);
			  emsSecuerNodeService.delete(ids);
    	}
      return success();
    }

    @ApiOperation(value="查询节点结构", notes="全部查询")
    @PostMapping(value = "/findAll")
    public RESTfulResult findAll(){
        List<EmsSecuerNode> list = emsSecuerNodeService.getNode();
        return success(list);
    }

    @ApiOperation(value="根据id和层级查询节点结构", notes="全部查询")
    @PostMapping(value = "/findIDAll")
    public RESTfulResult findIdAll(@RequestBody String id,Short tlevel){
        List<EmsSecuerNode> list = emsSecuerNodeService.getIDNode(id,tlevel);
        return success(list);
    }

}
