package com.steerinfo.ems.temergencymaterials.controller;

import com.steerinfo.auth.utils.JwtUtil;
import com.steerinfo.ems.Utils.DateUtils;
import com.steerinfo.ems.formula.model.Formula;
import com.steerinfo.ems.temergencymaterials.mapper.TEmergencymaterialsMapper;
import com.steerinfo.ems.temergencymaterials.model.TEmergencymaterials;
import com.steerinfo.ems.temergencymaterials.service.ITemergencymaterialsService;
import com.steerinfo.ems.tmaintenance.model.TMaintenance;
import com.steerinfo.ems.trmactitem.model.TRmActItem;
import com.steerinfo.ems.trmenergyproperty.model.TRmEnergyProperty;
import com.steerinfo.ems.trmunit.model.TRmUnit;
import com.steerinfo.framework.controller.BaseRESTfulController;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import com.steerinfo.framework.service.pagehelper.PageList;
import com.steerinfo.task.SpringCronTask;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.text.SimpleDateFormat;
import java.util.*;

@RestController
@RequestMapping("/${api.version}/temergencymaterials")
public class TEmergencymaterialsController extends BaseRESTfulController {
    private static final Logger logger = LoggerFactory.getLogger(SpringCronTask.class);

    @Autowired
    ITemergencymaterialsService temergencymaterialsService;

    @Autowired
    TEmergencymaterialsMapper emergencymaterialsMapper;

    @ApiOperation(value="获取列表", notes="分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer")
    })

    @GetMapping(value = "/")
    public RESTfulResult list(@RequestParam HashMap parmas, Integer pageNum, Integer pageSize){
        PageHelper.startPage(pageNum, pageSize);
        List<TEmergencymaterials> pList = emergencymaterialsMapper.PageselectAll(parmas);
        PageList list = new PageList(pList);
        return success(list);
    }

    @GetMapping(value = "/like/")
    public RESTfulResult listLike(@RequestParam HashMap parmas,Integer pageNum, Integer pageSize){
        if(parmas.containsKey("gx_name") && parmas.get("gx_name") != null && !"".equals(parmas.get("gx_name").toString())){
            String gx_name = parmas.get("gx_name").toString();
            if(gx_name.indexOf(",") == -1){
                parmas.put("gx_name", "and gx_name = '" + gx_name + "'");
            } else {
                gx_name = "and gx_name in ('" + gx_name.replaceAll(",", "','") + "')";
                parmas.put("gx_name", gx_name);
            }
        }
        PageHelper.startPage(pageNum, pageSize);
        List<TEmergencymaterials> pList = emergencymaterialsMapper.PageselectLikeAll(parmas);
        PageList list = new PageList(pList);
        return success(list);
    }

    @GetMapping("/getAll")
    public RESTfulResult getall() {
        List<TEmergencymaterials> tEmergencymaterials = temergencymaterialsService.selectAll();
        return success(tEmergencymaterials);
    }

    @GetMapping("/getGxName")
    public RESTfulResult getGxName() {
        List<String> Gxlists = temergencymaterialsService.selectGxAll();
        return success(Gxlists);
    }

    @GetMapping("/getDw")
    public RESTfulResult getDw() {
        List<String> Gxlists = temergencymaterialsService.selectDwAll();
        return success(Gxlists);
    }
    @ApiOperation(value="创建", notes="根据TEmergencymaterials对象创建")
    @ApiImplicitParam(name = "TEmergencymaterials", value = "详细实体TEmergencymaterials", required = true, dataType = "TEmergencymaterials")
    @PostMapping(value = "/")
    public RESTfulResult add(@ModelAttribute TEmergencymaterials model){
        String gx_name = model.getGx_name();
        String gx_code = emergencymaterialsMapper.getGxCodeByGxname(gx_name);
        Date date = new Date();
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd hh:mm:ss");
        String Dcjsj = simpleDateFormat.format(date);
        Integer tno = emergencymaterialsMapper.selectMaxTno();
        model.setGx_code(gx_code);
        model.setTno((tno+1));
        model.setCjr(JwtUtil.getUseridByToken());
        model.setCjsj(Dcjsj);
        emergencymaterialsMapper.add(model);
        return success();
    }

    @ApiOperation(value="删除", notes="根据用户ID来指定删除对象")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "String")
    @DeleteMapping(value = "/{id}")
    public RESTfulResult delete(@PathVariable String id){
        List<String> Ids = Arrays.asList(id.split(","));
        for(int i = 0;i < Ids.size();i++) {
            emergencymaterialsMapper.deleteByTnoKey(Ids.get(i));
        }
        return success();
    }

    @ApiOperation(value="批量更新详细信息", notes="根据传过来的TEmergencymaterials数组信息来更新详细信息")
    @ApiImplicitParam(name = "TEmergencymaterials", value = "详细实体TEmergencymaterials", required = true, dataType = "TEmergencymaterials")
    //@RequiresPermissions("trmworkproc:update")
    @PutMapping(value = "/", produces  = "application/json;charset=UTF-8")
    public RESTfulResult batchupdate(@RequestBody TEmergencymaterials[] model){
        for(int i = 0;i < model.length;i++){
            String gx_name = model[i].getGx_name();
            String gx_code = emergencymaterialsMapper.getGxCodeByGxname(gx_name);
            model[i].setGx_code(gx_code);
            emergencymaterialsMapper.batchupdate(model[i]);
        }
        return success();
    }
}
